{ config, lib, pkgs, ... }:
{
  imports = [
    ./hardware-configuration.nix
    ../../modules
    ../../users/simon

    ./services/dnsmasq.nix
    ./services/grafana.nix
    ./services/media.nix
    ./services/prometheus.nix
    ./services/scan.nix
    ./services/torrent.nix
    ./services/wordclock-dimmer.nix
  ];

  sbruder = {
    wireguard.home.enable = true;
    nginx.hardening.enable = true;
    restic.system = {
      enable = true;
      extraPaths = [
        "/data"
      ];
      extraExcludes = [
        "/data/media/video"
        "/data/misc"
        "/data/torrent"
      ];
    };
  };

  services.nginx = {
    enable = true;

    recommendedGzipSettings = true;
    recommendedOptimisation = true;
    recommendedProxySettings = true;
    recommendedTlsSettings = true;

    virtualHosts."fuuko.home.sbruder.de" = {
      enableACME = true;
      forceSSL = true;
    };
  };
  networking.firewall.allowedTCPPorts = [ 80 443 ];
  users.users.nginx.extraGroups = [ "keys" ];

  networking.hostName = "fuuko";

  system.stateVersion = "20.09";
}
